Scans script files (.R, .Rmd, .Rnw, .Rpres) for external package dependencies indicated by
library(), require() or :: and adds those packages to the Imports field in
the package DESCRIPTION.
add_dependencies_to_description(
path = getwd(),
description_file = "DESCRIPTION",
just_packages = FALSE
)location of individual file or directory where to search for scripts.
location of description file to be updated.
just give back a character vector of the found packages.